@@ -77,7 +77,7 @@ class PCA:
 	fit_transform = transform
 
 	@property
-	def variance_ratio(self):
+	def variance_ratios(self):
 		"""
 		:rtype: list[float]
 		"""
@@ -89,3 +89,15 @@ class PCA:
 		:rtype: list[str]
 		"""
 		return self._pca_columns
+
+	@property
+	def variance_ratio_by_column(self):
+		"""
+		:rtype: dict[str, float]
+		"""
+		variance_ratios = self.variance_ratios
+		pca_columns = self.pca_columns
+		if len(variance_ratios) != len(pca_columns):
+			raise RuntimeError(f'There are {len(variance_ratios)} variance ratios for {len(pca_columns)} columns!')
+
+		return {column: variance_ratio for column, variance_ratio in zip(pca_columns, variance_ratios)}
